{
  config,
  pkgs,
  lib,
  ...
}:
with lib; let
  psCfg = config.pub-solar;
  xdg = config.home-manager.users."${psCfg.user.name}".xdg;
in {
  hardware.cpu.amd.updateMicrocode = true;

  hardware.opengl.extraPackages = with pkgs; [
    rocm-opencl-icd
    rocm-opencl-runtime
  ];

  hardware.keyboard.uhk.enable = true;

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  boot.plymouth.enable = true;

  pub-solar.core.hibernation.enable = true;
  pub-solar.core.hibernation.resumeDevice = "/dev/dm-0";
  pub-solar.core.hibernation.resumeOffset = 77568000;

  pub-solar.terminal-life.full = true;

  networking.hostName = "chocolatebar";

  environment.systemPackages = with pkgs; [
    drone-docker-runner
    stdenv.cc.cc.lib
    hplip
    uhk-agent
  ];

  services.udev.extraRules = ''
    SUBSYSTEMS=="usb", ATTRS{idVendor}=="04f9", ATTRS{idProduct}=="209e", ATTRS{serial}=="000W0H924252", MODE="0664", GROUP="lp", SYMLINK+="usb/lp0"
  '';

  home-manager.users."${psCfg.user.name}" = {
    xdg.configFile = {
      "sway/config.d/10-autostart.conf".source = ./.config/sway/config.d/autostart.conf;
      "sway/config.d/10-input-defaults.conf".source = ./.config/sway/config.d/input-defaults.conf;
      "sway/config.d/10-screens.conf".source = ./.config/sway/config.d/screens.conf;
    };

    home.sessionVariables = {
      NIX_CC = "${pkgs.stdenv.cc}";
    };

    home.packages = with pkgs; [
      lmms
      audacity
    ];
  };

  musnix = {
    enable = true;
    kernel.realtime = true;
  };

  # For OpenProject development with https
  security.pki.certificates = [
    (builtins.readFile ./step-roots.pem)
  ];

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "20.09"; # Did you read the comment?
}
